@@ -7,9 +7,11 @@
 import os
 import stat
 from contextlib import contextmanager
+from time import sleep
 
 import ddt
 from dogtail.predicate import GenericPredicate
+from dogtail.rawinput import keyCombo
 from gi.repository import GLib
 
 from . import BaseTest
@@ -45,8 +47,8 @@ class BackupTest(BaseTest):
         with self.new_files():
             self.walk_initial_backup(app)
 
-        app.button("Back Up Now").click()
         with self.new_files():
+            app.button("Back Up Now").click()
             self.walk_incremental_backup(app)
 
     def test_from_commandline(self):
@@ -54,14 +56,23 @@ class BackupTest(BaseTest):
         with self.new_files():
             self.walk_initial_backup(app)
 
-        app = self.cmd("--backup")
         with self.new_files():
+            app = self.cmd("--backup")
             self.walk_incremental_backup(app)
 
     def test_from_monitor(self):
         self.set_boolean("periodic", True)
 
-        app = self.monitor()
+        self.monitor()
+        keyCombo("<Super>v")
+        sleep(1)
+        keyCombo("Enter")
+        app = self.get_app()
+
+        # ensure window has focus (different modes either get rid of
+        # notification drawer or not...)
+        app.child(name="Includes").click()
+
         with self.new_files():
             self.walk_initial_backup(app)
 
@@ -95,14 +106,15 @@ class BackupTest(BaseTest):
             app = self.cmd("--backup")
             self.walk_initial_backup(app, password="t")
 
+        last_backup = self.get_string("last-backup")
+        last_run = self.get_string("last-run")
+
         self.randomize_srcdir()
         app = self.cmd("--backup")
         if initial:
-            window = app.window("Back Up")
-            self.walk_initial_backup(app, password="t", wait=False)
+            window = self.walk_initial_backup(app, password="t", wait=False)
         else:
-            window = app.window("Backing Up…")
-            self.walk_incremental_backup(app, password="t", wait=False)
+            window = self.walk_incremental_backup(app, password="t", wait=False)
 
         def mid_progress():
             bar = window.findChild(
@@ -117,10 +129,12 @@ class BackupTest(BaseTest):
             app.button("Resume Later").click()
             self.wait_for(lambda: window.dead)
 
+        assert last_backup == self.get_string("last-backup")
+        assert last_run != self.get_string("last-run")
+
         app = self.cmd("--backup")
-        window = app.window("Backing Up…")
         self.walk_incremental_backup(app, password="nope", wait=False)
-        self.walk_incremental_backup(app, password="t", wait=False)
+        window = self.walk_incremental_backup(app, password="t", wait=False)
         self.did_resume = False
 
         def finish_progress():
@@ -159,3 +173,23 @@ class BackupTest(BaseTest):
         app = self.cmd("--backup")
         self.walk_incremental_backup(app, password="nope", wait=False)
         self.walk_incremental_backup(app, password="t")
+
+    def test_nag_check(self):
+        app = self.cmd("--backup")
+        self.walk_initial_backup(app, password="t", remember=True)
+
+        # One backup just to confirm we don't need password
+        app = self.cmd("--backup")
+        self.walk_incremental_backup(app)
+
+        months_ago = GLib.DateTime.new_now_utc().add_months(-2).format_iso8601()
+        self.set_string("nag-check", months_ago)
+
+        app = self.cmd("--backup")
+        # Wait for prompt (a little longer to appear than normal dogtail timeouts)
+        self.wait_for(lambda: app.isChild(roleName="text", label="Encryption password"))
+        self.walk_incremental_backup(app, password="nope", title="Restore Test", wait=False)
+        self.walk_incremental_backup(app, password="t", title="Restore Test", wait=False)
+        app.button("Close").click()  # we have a confirmation screen after nag
+
+        assert self.get_string("nag-check") != months_ago
