@@ -21,6 +21,8 @@ class RestoreTest(BaseTest):
         self.folder = self.get_config(
             "default", "folder", fallback="deja-dup-test", required=False
         )
+        self.filename = self.srcdir + "/[t](e?s*)' t.\"txt"
+        open(self.filename, "w").write("hello")
 
     def walk_backup(self, app):
         window = app.window("Back Up")
@@ -47,21 +49,29 @@ class RestoreTest(BaseTest):
         self.wait_for(lambda: window.dead, timeout=60)
 
     def walk_restore(self, app, password=None, error=False):
-        window = app.window("Restore From Where?")
-
         shutil.rmtree(self.srcdir)
 
-        window.button("Forward").click()  # from where
-        window.button("Forward").click()  # when
-        window.button("Forward").click()  # to where
-        window.button("Restore").click()  # summary
+        window = app.window("Restore From Where?")
+        window.button("Search").click()  # from where
+
+        # Switched to restore pane. Now select all.
+        search = app.button("Select")
+        self.wait_for(lambda: search.sensitive)
+        search.click()
+        app.child(
+            roleName="toggle button", name="Click on items to select them"
+        ).click()
+        app.button("Select All").click()
+
+        # And start restore
+        app.button("Restore").click()
+        window = app.window("Restore to Where?")
+        window.button("Restore").click()  # to where
 
         if password:
             window.child(roleName="text", label="Encryption password").text = password
             window.button("Forward").click()
 
-        window.childNamed("Restoring…")
-
         title = "Restore Failed" if error else "Restore Finished"
         self.wait_for(
             lambda: window.findChild(
@@ -71,7 +81,7 @@ class RestoreTest(BaseTest):
         )
         window.button("Close").click()
 
-        test_file = open(self.srcdir + "/test.txt", "r")
+        test_file = open(self.filename, "r")
         assert test_file.read(None) == "hello"
 
     def test_simple_cycle(self):
@@ -80,7 +90,7 @@ class RestoreTest(BaseTest):
         app.button("Create My First Backup").click()
         self.walk_backup(app)
 
-        self.set_string("last-backup", "")  # to go back to welcome screen
+        self.set_string("last-run", "")  # to go back to welcome screen
         app.button("Restore From a Previous Backup").click()
         self.walk_restore(app)
 
